#!/bin/bash
#
# Component: repositoryhandler
#
# Description: returns the file system stats in the mounts of a given repository
#
# usage: getFSStats.sh <repository> [fast]
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

if [  -z "$1" ] ; then
    exit 1
fi

if [ ! -d "$1" ] ; then
    exit 1
fi

# call getProp confFile propName
# val=`getProp "./test.cfg" "mountPoints"`
function getProp {
	sed -n "s;^$2=;;p" $1|sed 's/"//g' 
	#	eval "(unset $2; . $1; echo \$$2)" # this removes backslash characters :(
}

# checks whether a mount accupies a whole partition
# prints "true" if the fs is mounted into the mount directory or mount directory is the only directory on the partition (apart from lost+found).
function isMountDedicated {
    local mntAbs=`readlink -n -f $1`
    local fsAbs=`df -P -k $1 | tail -n +2 |awk '{print \$6}'|xargs readlink -n -f`
    if [ "$mntAbs" == "$fsAbs" ] ; then
		echo "true"
		return
    fi
    local mntParent=`dirname $mntAbs`
    if [ "$mntParent" != "$fsAbs" ] ; then
		echo "false"
		return
    fi
    local dirCnt=`ls -1 $fsAbs|grep -v "^lost+found$"|wc -l`
    if [ $dirCnt == 1 ] ; then
		echo "true"
		return
    fi
    echo "false"
}

#find out how many studies to recalculate
if [ "$2" != "fast" ] ; then
	configfile=$CONF/checkspacerecalc.cfg
	if [ ! -f $configfile ] ; then 
		configfile=$CASES_HOME/checkspacerecalc.cfg
	fi
	if [ -f $configfile ] ; then 
		dayofweek=`date +%u`
		dayofmonth=`date +%e`
		recalc=`cat $configfile | grep -v "#" | LC_NUMERIC=en_US awk -vFS="=" -vDAYOFWEEK="$dayofweek" -vDAYOFMONTH="$dayofmonth" '
		BEGIN {
			recalc = 0;
			usual = 0;
			large = 100000;
		}			
		$1 == "day" {
			day = $2;
		}
		$1 == "week" {
			week = $2;
		}
		$1 == "usual" {
			usual = $2;
		}
		$1 == "large" {
			large = $2;
		}
		END {
			recalc = usual;
			if( day != 0 ) {
				if( week == 0 ) {
					if( day == DAYOFWEEK ) {
						recalc = large;
					}
				}
				else {
					if( ( day == DAYOFWEEK ) &&
						( DAYOFMONTH > ( week - 1 ) * 7 ) &&
						( DAYOFMONTH <= week * 7 )           ) {
						recalc = large;
					}
				}
			}	
			print( recalc );
		}	
	'`
	else
		recalc=0
	fi
fi


legacyDir=`getProp $1/repository.cfg legacyDir`

if [ -n "$legacyDir" ] ; then
	if [ "$2" != "fast" ] ; then
		if [ "$(isMountDedicated $legacyDir)" == "true" ] ; then
			legacysize="DEDICATED"
		elif [ "$(getProp $1/repository.cfg legacyCountSize)" != "false" ] ; then
			#for debugging only
			cp $legacyDir/.count $legacyDir/.count.save
	
			legacysize=`$REPOSITORY_HANDLER_HOME/bin/countSize $legacyDir $recalc legacy`
		else
			legacysize="NA"
		fi
	fi
	df -P -k $legacyDir | tail -n +2 | if read fs total used free etc ; then
		[ "$legacysize" == "DEDICATED" ] && legacysize="$used"
		echo "FS=$fs"
		echo "TOTAL=$total"
		echo "USED=$used"
		[ "$2" != "fast" ] && echo "MYUSED=$legacysize"
		echo "FREE=$free"
		df -P -i $legacyDir | tail -n +2 | if read fsI totalI usedI freeI etc ; then
			echo "INODESTOTAL=$totalI"
			echo "INODESUSED=$usedI"
		fi	
	fi
fi

mounts=`getProp $1/repository.cfg mountPoints`
if [ -z $mounts ] ; then
	if [ "$2" != "fast" ] ; then 
		
		if [ "$(isMountDedicated $1)" == "true" ] ; then
			repositorysize="DEDICATED"
		elif [ "$(getProp $1/repository.cfg countSize)" != "false" ] ; then
			#for debugging only
			cp $1/.count $1/.count.save
	
			repositorysize=`$REPOSITORY_HANDLER_HOME/bin/countSize $1 $recalc`
		else
			repositorysize="NA"
		fi
	fi	
	df -P -k $1 | tail -n +2 | if read fs total used free etc ; then
		[ "$repositorysize" == "DEDICATED" ] && repositorysize="$used"
		echo "FS=$fs"
		echo "TOTAL=$total"
		echo "USED=$used"
		[ "$2" != "fast" ] && echo "MYUSED=$repositorysize"
		echo "FREE=$free"
		df -P -i $1 | tail -n +2 | if read fsI totalI usedI freeI etc ; then
			echo "INODESTOTAL=$totalI"
			echo "INODESUSED=$usedI"
		fi	
	fi
else
	mounts=`echo "$mounts"|sed 's/[.\.]/ /g'`
	for mount in $mounts ; do
		if [ -f $1/$mount/repositorypart.cfg ] ; then
			if [ "$2" != "fast" ] ; then 
				if [ "$(isMountDedicated $1/$mount)" == "true" ] ; then
					mountsize="DEDICATED"
				elif [ "$(getProp $1/$mount/repositorypart.cfg countSize)" != "false" ] ; then
					#for debugging only
					cp $1/$mount/.count $1/$mount/.count.save
			
					mountsize=`$REPOSITORY_HANDLER_HOME/bin/countSize $1/$mount $recalc`
				else
					mountsize="NA"
				fi
			fi			
			df -P -k $1/$mount | tail -n +2 | if read fs total used free etc ; then
				[ "$mountsize" == "DEDICATED" ] && mountsize="$used"
				echo "FS=$fs"
				echo "TOTAL=$total"
				echo "USED=$used"
				[ "$2" != "fast" ] && echo "MYUSED=$mountsize"
				echo "FREE=$free"
				df -P -i $1/$mount | tail -n +2 | if read fsI totalI usedI freeI etc ; then
					echo "INODESTOTAL=$totalI"
					echo "INODESUSED=$usedI"
				fi	
			fi
		fi
	done
fi
